==> moodle_1.3.1.orig.tar.gz: moodle/lang/it/editor.php <==
<?PHP // $Id: editor.php,v 1.5 2004/05/20 12:10:54 bobopinna Exp $ 
      // editor.php - created with Moodle 1.3 Nearly Ready (2004052000)


$string['about'] = 'Info su questo editor';
$string['absbottom'] = 'Inferiore assoluto';
$string['absmiddle'] = 'Centro assoluto';
$string['address'] = 'Indirizzo';
$string['alignment'] = 'Allineamento';
$string['alternatetext'] = 'Testo alternativo';
$string['baseline'] = 'Linea di base';
$string['bold'] = 'Grassetto';
$string['borderthickness'] = 'Spessore bordo';
$string['bottom'] = 'Inferiore';
$string['browse'] = 'Naviga';
$string['cancel'] = 'Annulla';
$string['cellpadding'] = 'Margine celle';
$string['cellspacing'] = 'Spaziatura celle';
$string['choosechar'] = 'Scegli carattere';
$string['chooseicon'] = 'Scegli una icona da inserire';
$string['close'] = 'Chiudi';
$string['cols'] = 'Colonne';
$string['copy'] = 'Copia selezione';
$string['createfolder'] = 'Crea cartella';
$string['createlink'] = 'Inserisci collegamento web';
$string['cut'] = 'Taglia selezione';
$string['delete'] = 'Cancella';
$string['filebrowser'] = 'Gestione file';
$string['forecolor'] = 'Colore testo';
$string['fullscreen'] = 'Editor a schermo intero';
$string['heading'] = 'Intestazione';
$string['height'] = 'Altezza';
$string['hilitecolor'] = 'Colore sfondo';
$string['horizontal'] = 'Orizzontale';
$string['horizontalrule'] = 'Riga orizzontale';
$string['htmlmode'] = 'Mostra sorgente HTML';
$string['imageurl'] = 'URL immagine';
$string['indent'] = 'Aumenta nidificazione';
$string['insertchar'] = 'Inserisci carattere speciale';
$string['insertimage'] = 'Inserisci immagine';
$string['insertlink'] = 'Inserisci collegamento';
$string['insertsmile'] = 'Inserisci faccina';
$string['inserttable'] = 'Inserisci tabella';
$string['italic'] = 'Italico';
$string['justifycenter'] = 'Centrato';
$string['justifyfull'] = 'Guistificato';
$string['justifyleft'] = 'Sinistra';
$string['justifyright'] = 'Destra';
$string['layout'] = 'Schema';
$string['left'] = 'Sinistra';
$string['lefttoright'] = 'Direzione da sinistra a destra';
$string['linkproperties'] = 'Propriet collegamento';
$string['linktarget'] = 'destinazione';
$string['linktargetblank'] = 'Nuova finestra';
$string['linktargetnone'] = 'Niente';
$string['linktargetother'] = 'Altro (fuori servizio)';
$string['linktargetself'] = 'Stesso frame';
$string['linktargettop'] = 'Stessa finestra';
$string['linktitle'] = 'Titolo';
$string['linkurl'] = 'URL';
$string['middle'] = 'Centro';
$string['minimize'] = 'Minimizza editor';
$string['move'] = 'Muovi';
$string['normal'] = 'Normale';
$string['notimage'] = 'Il file selezionato non  un immagine. Prego scegliere un immagine!';
$string['notset'] = 'Non impostato';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Lista ordinata';
$string['outdent'] = 'Diminuisci nidificazione';
$string['paste'] = 'Incolla dagli appunti';
$string['path'] = 'Percorso';
$string['percent'] = 'Percentuale';
$string['pixels'] = 'Punti';
$string['popupeditor'] = 'Editor in nuova finestra';
$string['preformatted'] = 'Preformattato';
$string['preview'] = 'Anteprima';
$string['properties'] = 'Propriet';
$string['redo'] = 'Ripeti ultima azione';
$string['removelink'] = 'Elimina collegamento';
$string['rename'] = 'Rinomina';
$string['right'] = 'Destra';
$string['righttoleft'] = 'Direzione da destra a sinistra';
$string['rows'] = 'Righe';
$string['selectcolor'] = 'Selezione colore';
$string['selection'] = 'Selezione';
$string['showhelp'] = 'Aiuto sull\'editor';
$string['size'] = 'Dimensione';
$string['spacing'] = 'Spaziatura';
$string['strikethrough'] = 'Barrato';
$string['subscript'] = 'Pedice';
$string['superscript'] = 'Apice';
$string['textindicator'] = 'Stile corrente';
$string['textmode'] = 'Sei nel MODO TESTO. Utilizza il pulsante [<>] per tornare al MODO WYSIWYG.';
$string['texttop'] = 'Limite superiore testo';
$string['top'] = 'In alto';
$string['type'] = 'Tipo';
$string['underline'] = 'Sottolineato';
$string['undo'] = 'Annulla ultima azione';
$string['unorderedlist'] = 'Lista puntata';
$string['upload'] = 'Trasferisci file';
$string['vertical'] = 'Verticale';
$string['width'] = 'Larghezza';
$string['wordclean'] = 'Pulisci codice HTML generato da Word';
$string['zip'] = 'Comprimi';

?>

==> moodle_1.4.3.orig.tar.gz: moodle/lang/it/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.4 beta (2004082300)


$string['about'] = 'Info su questo editor';
$string['absbottom'] = 'Inferiore assoluto';
$string['middle'] = 'Centro assoluto';
$string['address'] = 'Indirizzo';
$string['alignment'] = 'Allineamento';
$string['alternatetext'] = 'Testo alternativo';
$string['anchorhelp'] = 'Questo crea solamente un ancora. E\' necessario creare un collegamento manualmente.';
$string['anchorname'] = 'Nome ancora';
$string['anchors'] = 'Ancore';
$string['baseline'] = 'Linea di base';
$string['bold'] = 'Grassetto';
$string['borderthickness'] = 'Spessore bordo';
$string['bottom'] = 'Inferiore';
$string['browse'] = 'Naviga';
$string['cancel'] = 'Annulla';
$string['cellpadding'] = 'Margine celle';
$string['cellspacing'] = 'Spaziatura celle';
$string['choosechar'] = 'Scegli carattere';
$string['chooseicon'] = 'Scegli una icona da inserire';
$string['close'] = 'Chiudi';
$string['cols'] = 'Colonne';
$string['copy'] = 'Copia selezione';
$string['createanchor'] = 'Crea ancora';
$string['createfolder'] = 'Crea cartella';
$string['createlink'] = 'Inserisci collegamento web';
$string['cut'] = 'Taglia selezione';
$string['delete'] = 'Cancella';
$string['filebrowser'] = 'Gestione file';
$string['forecolor'] = 'Colore testo';
$string['fullscreen'] = 'Editor a schermo intero';
$string['heading'] = 'Intestazione';
$string['height'] = 'Altezza';
$string['hilitecolor'] = 'Colore sfondo';
$string['horizontal'] = 'Orizzontale';
$string['horizontalrule'] = 'Riga orizzontale';
$string['htmlmode'] = 'Mostra sorgente HTML';
$string['imageurl'] = 'URL immagine';
$string['indent'] = 'Aumenta nidificazione';
$string['insertchar'] = 'Inserisci carattere speciale';
$string['insertimage'] = 'Inserisci immagine';
$string['insertlink'] = 'Inserisci collegamento';
$string['insertsmile'] = 'Inserisci faccina';
$string['inserttable'] = 'Inserisci tabella';
$string['italic'] = 'Italico';
$string['justifycenter'] = 'Centrato';
$string['justifyfull'] = 'Guistificato';
$string['justifyleft'] = 'Sinistra';
$string['justifyright'] = 'Destra';
$string['layout'] = 'Schema';
$string['left'] = 'Sinistra';
$string['lefttoright'] = 'Direzione da sinistra a destra';
$string['linkproperties'] = 'Propriet collegamento';
$string['linktarget'] = 'destinazione';
$string['linktargetblank'] = 'Nuova finestra';
$string['linktargetnone'] = 'Niente';
$string['linktargetother'] = 'Altro (fuori servizio)';
$string['linktargetself'] = 'Stesso frame';
$string['linktargettop'] = 'Stessa finestra';
$string['linktitle'] = 'Titolo';
$string['linkurl'] = 'URL';
$string['middle'] = 'Centro';
$string['minimize'] = 'Minimizza editor';
$string['move'] = 'Muovi';
$string['normal'] = 'Normale';
$string['notimage'] = 'Il file selezionato non  un immagine. Prego scegliere un immagine!';
$string['notset'] = 'Non impostato';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Lista ordinata';
$string['outdent'] = 'Diminuisci nidificazione';
$string['paste'] = 'Incolla dagli appunti';
$string['path'] = 'Percorso';
$string['percent'] = 'Percentuale';
$string['pixels'] = 'Punti';
$string['popupeditor'] = 'Editor in nuova finestra';
$string['preformatted'] = 'Preformattato';
$string['preview'] = 'Anteprima';
$string['properties'] = 'Propriet';
$string['redo'] = 'Ripeti ultima azione';
$string['removelink'] = 'Elimina collegamento';
$string['rename'] = 'Rinomina';
$string['right'] = 'Destra';
$string['righttoleft'] = 'Direzione da destra a sinistra';
$string['rows'] = 'Righe';
$string['selectcolor'] = 'Selezione colore';
$string['selection'] = 'Selezione';
$string['showhelp'] = 'Aiuto sull\'editor';
$string['size'] = 'Dimensione';
$string['spacing'] = 'Spaziatura';
$string['strikethrough'] = 'Barrato';
$string['subscript'] = 'Pedice';
$string['superscript'] = 'Apice';
$string['textindicator'] = 'Stile corrente';
$string['textmode'] = 'Sei nel MODO TESTO. Utilizza il pulsante [<>] per tornare al MODO WYSIWYG.';
$string['texttop'] = 'Limite superiore testo';
$string['top'] = 'In alto';
$string['type'] = 'Tipo';
$string['underline'] = 'Sottolineato';
$string['undo'] = 'Annulla ultima azione';
$string['unorderedlist'] = 'Lista puntata';
$string['upload'] = 'Trasferisci file';
$string['vertical'] = 'Verticale';
$string['width'] = 'Larghezza';
$string['wordclean'] = 'Pulisci codice HTML generato da Word';
$string['zip'] = 'Comprimi';

?>
